﻿using System;
using System.Diagnostics;
using Framework.Common;
using OpenQA.Selenium;
using OpenQA.Selenium.Chrome;
using OpenQA.Selenium.Interactions;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;

namespace BDDFramework
{
    public class TodoAppPlatformDriver : ITodoAppPlatformDriver
    {
        private ChromeDriver driver = null;
        public void Id()
        {
            Debug.WriteLine("JS Driver");
        }

        public void EnsureAppLoaded()
        {
            // open the app in the browser and check if specific elements exist
            this.driver = new ChromeDriver();
            this.driver.Manage().Timeouts().ImplicitlyWait(new TimeSpan(0, 0, 30));
            this.driver.Navigate().GoToUrl("http://localhost:44890/Todo");
            // check if input with ID "todo_text" exists
            IWebElement element = this.driver.FindElement(By.Id("todo_text"));
            if (element == null)
            {
                Assert.Fail("App did not load successfully. Element not found - todo_text");
            }
        }

        public void EnsureTaskListEmpty()
        {
            IWebElement list =  this.driver.FindElement(By.Id("tasklist"));
            if (list != null)
            {
                // ideally, we want to CLEAR the items, if there are any. (put the system in a given state)
                this.driver.Manage().Timeouts().ImplicitlyWait(new TimeSpan(0, 0, 1));
                ReadOnlyCollection<IWebElement> children = list.FindElements(By.TagName("li"));
                if (children.Count > 0)
                {
                    Assert.Fail("Tasks List must be empty");
                }
                this.driver.Manage().Timeouts().ImplicitlyWait(new TimeSpan(0, 0, 30));
            }
            else
            {
                Assert.Fail("Task List container element not found.");
            }
        }

        public string GetTaskText(int index)
        {
            IWebElement list = this.driver.FindElement(By.Id("tasklist"));
            if (list != null)
            {
                // ideally, we want to CLEAR the items, if there are any. (put the system in a given state)
                ReadOnlyCollection<IWebElement> children = list.FindElements(By.TagName("li"));
                if (children.Count > 0)
                {
                    return children[children.Count - 1].Text;
                }
            }
            return null;
        }

        public int GetTaskCount()
        {
            IWebElement list = this.driver.FindElement(By.Id("tasklist"));
            if (list != null)
            {
                // ideally, we want to CLEAR the items, if there are any. (put the system in a given state)
                ReadOnlyCollection<IWebElement> children = list.FindElements(By.TagName("li"));
                return children.Count;
            }
            return -1;
        }

        public void AddNewTask(string text)
        {
            // enter text in the todo_text input box
            this.driver.FindElement(By.Id("todo_text")).SendKeys(text);
            // click the Add Task button
            this.driver.FindElement(By.Id("addtask")).Click();
        }

        public void Cleanup()
        {
            this.driver.Quit();
        }
    }
}
