﻿using System;
using System.Diagnostics;
using Framework.Common;
using System.Windows.Automation;
using System.Windows.Automation.Text;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using System.Windows.Forms;

namespace BDDFramework
{
    public class TodoAppPlatformDriver : ITodoAppPlatformDriver
    {
        private Process process = null;
        private AutomationElement appWindow = null;
        public void Id()
        {
            Debug.WriteLine("WPF Driver");
        }

        public void EnsureAppLoaded()
        {
            // start executable
            this.process = Process.Start(@"C:\Users\ATodorov\Desktop\ISTA\TODOApp\TODOApp.WPF\bin\Debug\TODOApp.WPF.exe");
            this.process.WaitForInputIdle();
            System.Threading.Thread.Sleep(1000);
            // check if textbox with name "TextBox" exists in the app
            this.appWindow = AutomationElement.RootElement.FindFirst(TreeScope.Children, new PropertyCondition(AutomationElement.ProcessIdProperty, this.process.Id));
            if (this.appWindow == null)
            {
                Assert.Fail("cannot find app.");
            }
            AutomationElement textbox = this.appWindow.FindFirst(TreeScope.Descendants, new PropertyCondition(AutomationElement.ControlTypeProperty, ControlType.Edit));
            if (textbox == null)
            {
                Assert.Fail("App did not load successfully - no text box found.");
            }
        }

        public void EnsureTaskListEmpty()
        {
            // get listbox
            AutomationElement listView = this.appWindow.FindFirst(TreeScope.Descendants, new PropertyCondition(AutomationElement.AutomationIdProperty, "ListView1"));
            //check children
            AutomationElementCollection tasks = listView.FindAll(TreeScope.Children, new PropertyCondition(AutomationElement.ControlTypeProperty, ControlType.DataItem));
            Assert.AreEqual(0, tasks.Count);
        }

        public void AddNewTask(string text)
        {
            // enter text in the input box
            AutomationElement textbox = this.appWindow.FindFirst(TreeScope.Descendants, new PropertyCondition(AutomationElement.ControlTypeProperty, ControlType.Edit));
            //ValuePattern valuePattern = textbox.GetCurrentPattern(ValuePattern.Pattern);
            textbox.SetFocus();
            SendKeys.SendWait(text);
            AutomationElement button = this.appWindow.FindFirst(TreeScope.Descendants, new PropertyCondition(AutomationElement.AutomationIdProperty, "Button1"));
            InvokePattern invokePattern = (InvokePattern)button.GetCurrentPattern(InvokePattern.Pattern);
            invokePattern.Invoke();
          //  System.Threading.Thread.Sleep(1000);
        }

        public string GetTaskText(int index)
        {
            // get listbox
            AutomationElement listView = this.appWindow.FindFirst(TreeScope.Descendants, new PropertyCondition(AutomationElement.AutomationIdProperty, "ListView1"));
            //check children
            AutomationElementCollection tasks = listView.FindAll(TreeScope.Children, new PropertyCondition(AutomationElement.ControlTypeProperty, ControlType.DataItem));
            AutomationElement task = tasks[index];
           // AutomationElement textElement = task.FindFirst(TreeScope.Children, new PropertyCondition(AutomationElement.ControlTypeProperty, ControlType.Text));
          //  return (string)textElement.GetCurrentPropertyValue(AutomationElement.NameProperty);
            return (string)task.GetCurrentPropertyValue(AutomationElement.NameProperty);
        }

        public int GetTaskCount()
        {
            // get listbox
            AutomationElement listView = this.appWindow.FindFirst(TreeScope.Descendants, new PropertyCondition(AutomationElement.AutomationIdProperty, "ListView1"));
            //check children
            AutomationElementCollection tasks = listView.FindAll(TreeScope.Children, new PropertyCondition(AutomationElement.ControlTypeProperty, ControlType.DataItem));
            return tasks.Count;
        }

        public void Cleanup()
        {
            this.process.Kill();
        }
    }
}
