﻿using System;
using System.Diagnostics;
using Framework.Common;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace BDDFramework
{
    public class TodoAppPlatformDriver : ITodoAppPlatformDriver
    {
        private IOSFranklyDriver driver = null;
        public void Id()
        {
            Debug.WriteLine("iOS Driver");
        }

        public void EnsureAppLoaded()
        {
            this.driver = new IOSFranklyDriver("http://10.14.1.137:37265");
            JArray results = this.driver.Find("textField index:0");
            if (results.Count == 0)
            {
                Assert.Fail("iOS app did not load successfully: couldn't find a textField component");
            }
        }

        public void EnsureTaskListEmpty()
        {
            JArray results = this.driver.Find("tableView");
            if (results.Count > 0)
            {
                // find list items
                JArray items = this.driver.Find("tableView tableViewCell");
                if (items.Count > 0)
                {
                    Assert.Fail("Task list is not empty.");
                }
            }
        }

        public void AddNewTask(string text)
        {
            // enter text
            this.driver.SetText("textField", text);
            // press button
            this.driver.Touch("button");
        }

        public string GetTaskText(int index)
        {
            JArray results = this.driver.Find("tableView");
            if (results.Count > 0)
            {
                // find list items
                JArray items = this.driver.Find("tableView tableViewCell tableViewCellContentView child label");
                if (items.Count > 0)
                {
                    return items[index]["label"].Value<string>();
                }
            }
            return null;
        }

        public int GetTaskCount()
        {
            JArray results = this.driver.Find("tableView");
            if (results.Count > 0)
            {
                // find list items
                JArray items = this.driver.Find("tableView tableViewCell");
                return items.Count;
            }
            return -1;
        }

        public void Cleanup()
        {

        }
    }
}
