﻿using System;
using System.Diagnostics;
using Framework.Common;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace BDDFramework
{
    public class TodoAppPlatformDriver : ITodoAppPlatformDriver
    {
        private AndroidFranklyDriver driver = null;
        public void Id()
        {
            Debug.WriteLine("Android Driver");
        }

        public void EnsureAppLoaded()
        {
            this.driver = new AndroidFranklyDriver("http://127.0.0.1:34777/");
            JArray results = this.driver.Find("editText index:0");
            if (results.Count == 0)
            {
                Assert.Fail("Android app did not load successfully: couldn't find an EditText component");
            }
        }

        public void EnsureTaskListEmpty()
        {
            JArray results = this.driver.Find("listView");
            if (results.Count > 0)
            {
                // find list items
                JArray items = this.driver.Find("listView TextView");
                if (items.Count > 0)
                {
                    Assert.Fail("Task list is not empty.");
                }
            }
        }

        public void AddNewTask(string text)
        {
            // enter text
            this.driver.SetText("editText", text);
            // press button
            this.driver.Touch("button");
            System.Threading.Thread.Sleep(1000);
        }

        public string GetTaskText(int index)
        {
            JArray results = this.driver.Find("listView");
            if (results.Count > 0)
            {
                // find list items
                JArray items = this.driver.Find("listView TextView");
                if (items.Count > 0)
                {
                    return items[index]["text"].Value<string>();
                }
            }
            return null;
        }

        public int GetTaskCount()
        {
            JArray results = this.driver.Find("listView");
            if (results.Count > 0)
            {
                // find list items
                JArray items = this.driver.Find("listView TextView");
                return items.Count;
            }
            return -1;
        }

        public void Cleanup()
        {

        }
    }
}
